%% EXHAUSTIVE SEARCH METHOD %%
%% Developed by Dr. Rajib Kuamr Bhattacharjya %%
%% Department of Civil Engineering, IIT Guwahati %%
%% This method is used to bracket the optiam of a minimization function
%% 'a' and 'b' are the upper bound and lower bound of search space 
%% 'n' is the number of division
%% funcName is the name of the function 
%% x1 and x2 are the bracket
%% k is the number of iteration required to bracket the optima
%% An example function 'func' has been provided
%% For bracketing minima of the function just excecute the Exhaustive
%% function using "[x1 x3 k]=Exhaustive(0,10,20,'func')" 
%% Where a=0,b=10, n=20 and funcName='func'

function [x1 x3 k]=Exhaustive(a,b,n,funcName)
% a is lower bound
% b is upper bound
% n is number of division
% funcName is the name of the objective function

x1=a;
delx=(b-a)/n;

x2=x1+delx;
x3=x2+delx;
fx1=feval(funcName,x1);
fx2=feval(funcName,x2);
fx3=feval(funcName,x3);

k=3;
while((fx1>=fx2) & (fx3<=fx2))
    x1=x2; x2=x3; x3=x2+delx;
    fx1=fx2; fx2=fx3; fx3=feval(funcName,x3);
    k=k+1;
end
   